VERSION 8000; ; 8300
* -----------------------------------------------------------------------------
* @filedoc
* @file Topo_LinienLaengen.CSX
* @brief Bsp. fr Lngenermittlung aus Linien 
* 
* Beispiel: Lngen von Linien/Linienelementen ermitteln: ber alle Schichten zu einem Linienkode
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author JH
* @endfiledoc
* -----------------------------------------------------------------------------
*       1 14.05.09 JH Version fr die 8.3 hergestellt
* @history
* -----------------------------------------------------------------------------

* Vereinbarungen -------------------------------------------------------------------------------

BILDSCHIRM GRAFIK                      | gibt die Meldungen im Arbeitsprotokoll aus

* Zuweisungen ----------------------------------------------------------------------------------

LinKode = 201                          | Linienkode fr Auswertung
LinArt  = 0                            | Steuerung zur Berechnung der Linienlngen: 0 = projezierte Lnge, 1 = Raumlnge
!LinBez = " "                          | Kodebezeichnung aus Kodetabelle

* Deklarationen --------------------------------------------------------------------------------

SYMBOLE /TOPOSYS/ TopoSys              | Symbol fr das System der Topografiedaten
SYMBOLE /TOPOLAYER/ Schicht            | Symbol fr die Schicht
SYMBOLE /TOPOLINE/ Linie               | Symbol fr die Topografielinie
SYMBOLE /TOPOLINEELEMENT/ Element      | Symbol fr das Linienelement
SYMBOLE /TOPOLINEINDEX/ XLinie         | Symbol fr das Linienindexobjekt

* Ausfhrungen ---------------------------------------------------------------------------------

* Systemobjekt
TopoSys = Project.GetTopoSys()                   | liefert das Objekt fr das System der Topografiedaten

* Schichtobjekt
Schicht = $NULL                                  | setzt die Schicht auf Null 
SOLANGE Schicht = TopoSys.GetNextLayer(Schicht)  | liest die Schichten fortlaufend aus
  !SchichtName = Schicht.GetName()               | liefert den Schichtnamen
  !SchichtBez = Schicht.GetDescription()         | liefert die Schichtbezeichnung
  MELDE "----------- Schicht '#': # ----------"; !SchichtName; !SchichtBez

* Linienindexobjekt
  XLinie = TopoSys.GetLineIndex(!SchichtName)    | liefert das Linienindexobjekt der Schicht
  XLinie.SetCodeRange(LinKode)                   | setzt den auszuwertenden Kodebereich

* Linienobjekt
  SOLANGE Linie = XLinie.GetNext()               | liest die Linien ber den Index aus
    !LinBez = Linie.GetCodeDescription()         | liefert die Kodebezeichnung der Linie
    LinNr = Linie.GetNumber()                    | liefert die Liniennummer 
    LinienLaenge !LinBez                         | ruft den Funktionsblock auf (mit bergabe der Kodebezeichnung)
  ENDE SOLANGE
ENDE SOLANGE

STOP

* Funktionsblock ------------------------------------------------------------------------------
* Elementlngen ermitteln, aufsummieren und protokollieren 

FUNKTION LinienLaenge: !Name
WENN Linie == $NULL DANN ZURUECK  

* Zuweisungen -------------------------

EleAnz       = Linie.GetElementCount()        | Anzahl der Linienelemente
GesamtLaenge = Linie.GetLength(LinArt)        | Lnge der Linien
Laenge       = 0
SummeLaenge  = 0

* Ausfhrungen ------------------------

MELDE   " Linienkode: #"; !Name
WENN LinArt == 1 DANN
  MELDE " Elemente: # Raumlnge: #.###"; EleAnz; GesamtLaenge   
SONST
  MELDE " Elemente: # Lnge: #.###"; EleAnz; GesamtLaenge   
WEITER
MELDE   " -------------------------" 
MELDE   " Nr Typ   Radius    Lnge"

* Elementobjekt
IEle = 1                                      | Index des Elementes
SOLANGE Element = Linie.GetElement(IEle)      | liefert ein Element
  Typ = Element.GetType()                     | liefert den Elementtyp 
  Rad = Element.GetRadius()                   | liefert den Radius des Elementes

  WENN IEle == 1 DANN                         | 1. Element wird gesondert behandelt, da Hilfselement
    MELDE "### ### ####.### ####.### Sttzelement fr 1. Punkt"; IEle; Typ; Rad; Laenge
  SONST
    Laenge = Element.GetLength(LinArt)        | liefert die Elementlnge
    MELDE "### ### ####.### ####.###"; IEle; Typ; Rad; Laenge
  WEITER

  IEle = IEle + 1
  SummeLaenge = SummeLaenge + Laenge
ENDE SOLANGE  

MELDE "========================="
MELDE "                 ####.###"; SummeLaenge

ENDE FUNKTION